<!-- SPDX-FileCopyrightText: 2025 Tymoteusz Blazejczyk <tymoteusz.blazejczyk@tymonx.com> -->
<!-- SPDX-License-Identifier: Apache-2.0 -->

# pytest-cocotb

Pytest plugin that enables using [pytest][] as the regression manager for running [cocotb][] tests.

[pytest]: https://docs.pytest.org
[cocotb]: https://www.cocotb.org
